Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Command ¶
type Command interface {
flags.Commander
// ShortDescription explains what this command does in one line
ShortDescription() string
// LongDescription explains what this verb does (without limitation in amount of lines)
LongDescription() string
}
Command is an interface of implementations of verbs (like "add", "remove" etc of "fittool add"/"fittool remove")
Click to show internal directories.
Click to hide internal directories.